/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.extension.exception;

import org.fortiss.tooling.kernel.extension.IExecutionTarget;

/**
 * Exception class for informing about failures during target execution.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 43D42AC76FC2B4B8DBD08AC0906B2982
 */
public class ExecutionFailedException extends Exception {

	/** Stores the failing execution target provider. */
	private final IExecutionTarget executionTarget;

	/** Stores the failed target input. */
	private final Object targetInput;

	/** Constructor. */
	public ExecutionFailedException(IExecutionTarget target,
			Object input) {
		this.executionTarget = target;
		this.targetInput = input;
	}

	/** Returns the execution target, which failed. */
	public IExecutionTarget getExecutionTarget() {
		return executionTarget;
	}

	/** Returns the execution input, which might have caused the failure. */
	public Object getTargetInput() {
		return targetInput;
	}
}
